@@ -99,10 +99,14 @@ class JUnitXmlResult(unittest.TestResult):
         self._results.append(' />\n')
 
     def addSkip(self, test, reason):
-        self._super().addSkip(test, reason)
+        try:
+            self._super().addSkip(test, reason)
+        except AttributeError:
+            # Python < 2.7|3.1
+            pass
         self._test_case_string(test)
         self._results.append('>\n')
-        self._results.append('<skip type="%s.%s">%s</skip>\n</testcase>\n'% (escape(error[0].__module__), escape(error[0].__name__), escape(reason)))
+        self._results.append('<skip>%s</skip>\n</testcase>\n'% escape(reason))
 
     def addUnexpectedSuccess(self, test):
         self._super().addUnexpectedSuccess(test, error)
